import os

from ctypes import *

def find_file(name, path):
    """Search for file within specific dir and any child dirs.
    Args:
    name (str): Filename to be searched for.
    path (str): Dir path to search for file.
    Returns:
    str: Full path of found file (if found).
    bool: If file not found, returns false.
    """
    for root, _, files in os.walk(path):
        if name in files:
            return os.path.join(root, name)
    return False

lib = cdll.LoadLibrary(find_file("display_status_bin.so", "../"))

# define class GoString to map:
# C type struct { const char *p; GoInt n; }
class GoString(Structure):
    _fields_ = [("p", c_char_p), ("n", c_longlong)]

# define class GoSlice to map to:
# C type struct { void *data; GoInt len; GoInt cap; }
class GoSlice(Structure):
    _fields_ = [("data", POINTER(GoString)), ("len", c_longlong), ("cap", c_longlong)]

def to_go_string(url):
    url = bytes(url, 'utf-8')
    return GoString(url, len(url.decode()))

def to_go_slice(*urls):
    return GoSlice((GoString * len(urls))(*urls), len(urls), len(urls))

lib.DisplayLinks.argtypes = [GoSlice]
lib.DisplayLinks.restype = c_longlong
def display_status(*urls):
    urls = [to_go_string(url) for url in urls]
    lib.DisplayLinks(to_go_slice(*urls))



import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="display_status",
    version="1.0.0-1",
    description="Displays the status of links",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/KingAkeem/display_status",
    author="Akeem King",
    author_email="akeemtlking@gmail.com",
    license="GNU GPLv3",
    classifiers=[
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
    ],
    packages=find_packages(),
    include_package_data=True,
    eager_resources=['display_status_bin.so', 'display_status_bin.h', 'main.go'],
    package_data={
        '': 'display_status_bin.so',
        '': 'display_status_bin.h',
        '': 'main.go'
    }
)

